@@ -91,7 +91,6 @@ static struct option long_options[] =
 	{"stream", no_argument, 0, 34},
 	{"quit-on-f3", no_argument, 0, 35},
 	{"wait", required_argument, 0, 36},
-	{"hold-stream", required_argument, 0, 37},
 	{"skip-columns-like", required_argument, 0, 38},
 	{"pgcli-fix", no_argument, 0, 39},
 	{"style", required_argument, 0, 's'},
@@ -105,6 +104,11 @@ static struct option long_options[] =
 	{"querystream", no_argument, 0, 44},
 	{"menu-always", no_argument, 0, 45},
 	{"no-last-row-search", no_argument, 0, 46},
+	{"no-progressive-load", no_argument, 0, 47},
+	{"no-implicit-stream", no_argument, 0, 48},
+	{"custom-style-name", required_argument, 0, 49},
+	{"highlight-odd-rec", no_argument, 0, 50},
+	{"hide-header-line", no_argument, 0, 51},
 	{0, 0, 0, 0}
 };
 
@@ -152,7 +156,7 @@ buildargv(const char *input, int *_argc, char *appname)
 			if (argc >= (maxargc - 1))
 			{
 				maxargc *= 2;
-				argv = (char **) realloc(argv, maxargc * sizeof (char *));
+				argv = (char **) srealloc(argv, maxargc * sizeof (char *));
 				argv[argc] = NULL;
 			}
 
@@ -263,10 +267,14 @@ print_versions(void)
 
 #endif
 
-#ifdef HAVE_INOTIFY
+#if defined(HAVE_INOTIFY)
 
 	fprintf(stdout, "with inotify support\n");
 
+#elif defined(HAVE_KQUEUE)
+
+	fprintf(stdout, "with kqueue support\n");
+
 #endif
 
 }
@@ -305,13 +313,13 @@ readargs(char **argv,
 					fprintf(stdout, "  -F, --quit-if-one-screen\n");
 					fprintf(stdout, "                           quit if content is one screen\n");
 					fprintf(stdout, "  --clipboard-app=NUM      specify app used by copy to clipboard (1, 2, 3)\n");
-					fprintf(stdout, "  --hold-stream=NUM        can reopen closed FIFO (0, 1, 2)\n");
 					fprintf(stdout, "  --interactive            force interactive mode\n");
 					fprintf(stdout, "  --ignore_file_suffix     don't try to deduce format from file suffix\n");
 					fprintf(stdout, "  --ni                     not interactive mode (only for csv and query)\n");
-					fprintf(stdout, "  --no-watch-file          don't watch inotify event of file\n");
 					fprintf(stdout, "  --no-mouse               don't use own mouse handling\n");
+					fprintf(stdout, "  --no-progressive-load    don't use progressive data load\n");
 					fprintf(stdout, "  --no-sigint-search-reset\n");
+					fprintf(stdout, "  --no-watch-file          don't watch inotify event of file\n");
 					fprintf(stdout, "                           without reset searching on sigint (CTRL C)\n");
 					fprintf(stdout, "  --no-sleep               without waits against flickering\n");
 					fprintf(stdout, "  --no-xterm-mouse-mode    don't use optional xterm mouse mode\n");
@@ -330,8 +338,11 @@ readargs(char **argv,
 					fprintf(stdout, "  --bold-labels            row, column labels use bold font\n");
 					fprintf(stdout, "  --bold-cursor            cursor use bold font\n");
 					fprintf(stdout, "  --border                 type of borders (0..2)\n");
+					fprintf(stdout, "  --custom-style=NAME      name of custom color style\n");
 					fprintf(stdout, "  --double-header          header separator uses double lines\n");
 					fprintf(stdout, "  --force-uniborder        replace ascii borders by unicode borders\n");
+					fprintf(stdout, "  --hide-header-line       hides header line\n");
+					fprintf(stdout, "  --highlight-odd-rec      use special style for odd records\n");
 					fprintf(stdout, "  --ignore-bad-rows        rows with wrong column numbers are ignored\n");
 					fprintf(stdout, "  --null=STRING            STRING used instead NULL\n");
 					fprintf(stdout, "\nSearching options\n");
@@ -513,7 +524,7 @@ readargs(char **argv,
 			case 31:
 				{
 					char   *nullstr;
-					int		size;
+					int		size = strlen(optarg);
 
 					nullstr = trim_quoted_str(optarg, &size);
 					if (size > 255)
@@ -546,14 +557,6 @@ readargs(char **argv,
 					return false;
 				}
 				break;
-			case 37:
-				state->hold_stream = atoi(optarg);
-				if (state->hold_stream < 0 || state->hold_stream > 2)
-				{
-					state->errstr = "hold-stream should be 0, 1 or 2";
-					return false;
-				}
-				break;
 			case 38:
 				opts->csv_skip_columns_like = sstrdup(optarg);
 				break;
@@ -669,6 +672,19 @@ readargs(char **argv,
 			case 46:
 				opts->last_row_search = false;
 				break;
+			case 47:
+				opts->progressive_load_mode = false;
+				break;
+			case 49:
+				opts->custom_theme_name = sstrdup(optarg);
+				break;
+			case 50:
+				opts->highlight_odd_rec = true;
+				break;
+			case 51:
+				opts->hide_header_line = true;
+				break;
+
 			default:
 				{
 					format_error("Try %s --help\n", argv[0]);
@@ -783,5 +799,9 @@ args_are_consistent(Options *opts, StateData *state)
 			opts->tsv_format = true;
 	}
 
+	/* use progressive load mode only for data */
+	if (opts->querystream)
+		opts->progressive_load_mode = false;
+
 	return true;
 }
